#
# spec file for package yast2-drbd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _fwdefdir %{_prefix}/lib/firewalld/services
Name:           yast2-drbd
Version:        5.0.0
Release:        1.6
Summary:        YaST2 - DRBD Configuration
License:        GPL-2.0-or-later
Group:          System/YaST
URL:            https://github.com/yast/yast-drbd
Source0:        %{name}-%{version}.tar.bz2
Source1:        drbd.firewalld.xml
BuildRequires:  firewall-macros
BuildRequires:  ruby
BuildRequires:  update-desktop-files
# SuSEFirewall2 replaced by Firewalld(fate#323460)
BuildRequires:  yast2 >= 4.0.39
BuildRequires:  yast2-devtools >= 4.2.2
Requires:       drbd >= 9.0
Requires:       yast2 >= 4.0.39
Requires:       yast2-ruby-bindings >= 1.0.0
Supplements:    autoyast(drbd)
ExcludeArch:    i586 s390

%description
YaST2 - Configuration of Distributed Replicated Block Devices. With
this module you can configure a distributed storage system, frequently
used on high availability (HA) clusters.

%prep
%setup -q

%build
%yast_build

%install
%yast_install
%yast_metainfo

mkdir -p %{buildroot}%{_fwdefdir}
install -m 644 %{SOURCE1} %{buildroot}%{_fwdefdir}/drbd.xml

%post
%firewalld_reload

%files
%{yast_yncludedir}
%{yast_clientdir}
%{yast_moduledir}
%{yast_desktopdir}
%{yast_metainfodir}
%{yast_scrconfdir}
%{yast_agentdir}
%license COPYING
%dir %{_prefix}/lib/firewalld
%dir %{_fwdefdir}
%{_fwdefdir}/drbd.xml
%{yast_icondir}

%changelog
* Wed Aug 30 2023 Josef Reidinger <jreidinger@suse.cz>
- 5.0.0 (bsc#1185510)
* Wed Apr 12 2023 Xin Liang <xliang@suse.com>
- Validate DRBD Device name (bsc#1207952)
- 4.6.1
* Fri Mar  3 2023 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.6.0 (bsc#1208913)
* Wed Apr  6 2022 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.5.0 (bsc#1198109)
* Fri May 21 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not make package noarch: we require a dependency (drbd) that
  is not available on all architectures (boo#1188857).
- Sync the ExcludeArch statement from drbd (ExcludeArch: i586 s390)
- 4.4.2
* Tue Apr 20 2021 Dirk Müller <dmueller@suse.com>
- stop packaging docdir, it only contained the license which
  is now in licensedir (bsc#1184897)
- spec file cleanups
- 4.4.1
* Tue Apr 20 2021 Ladislav Slezák <lslezak@suse.cz>
- 4.4.0
* Wed Aug 19 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Correct firewall directory for %%_libexecdir changes (bsc#1174075)
- 4.3.3
* Tue Aug 11 2020 nick wang <nwang@suse.com>
- Open ports for DRBD linstor packages (bsc#1175434)
- 4.3.2
* Mon Aug 10 2020 schubi@suse.de
- AutoYaST: Added supplements: autoyast(drdb) into the spec file
  in order to install this packages if the section has been defined
  in the AY configuration file (bsc#1146494).
- 4.3.1
* Thu Jul 23 2020 Ancor Gonzalez Sosa <ancor@suse.com>
- RPM Packaging: do not rely on libexecdir being expanded to
  /usr/lib, which is not always the case (bsc#1174075).
- 4.3.0
* Thu Oct 31 2019 nick wang <nwang@suse.com>
- jsc#SLE-5498, lvmetad is removed in lvm2 since 2.03.05
- 4.2.2
* Fri May 31 2019 Stasiek Michalski <hellcp@mailbox.org>
- Add metainfo (fate#319035)
- Revamp spec
- Replace GenericName with Comment
- 4.2.0
* Tue Apr  2 2019 Ladislav Slezak <lslezak@suse.cz>
- Removed unused BuildRequires (bsc#1131234)
- 4.2.0
* Sun Nov 25 2018 Stasiek Michalski <hellcp@mailbox.org>
- Provide icon with module (boo#1109310)
- 4.1.0
* Tue Oct 16 2018 schubi@suse.de
- Added license file to spec.
* Wed Aug 22 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Thu Jun 28 2018 schubi@suse.de
- Added additional searchkeys to desktop file (fate#321043).
- Version 4.0.3
* Fri Feb 23 2018 nwang@suse.com
- bsc#1082507, add missing colon for ruby instance
- Version 4.0.2
* Fri Jan 26 2018 nwang@suse.com
- SuSEFirewall2 replace by firewalld(fate#323460)
- Version 4.0.1
* Tue Nov 21 2017 nwang@suse.com
- Merge fixes of bsc#1069131 and bsc#1069132 to openSUSE TW and SLE15.
- Version 4.0.0
* Tue Nov 21 2017 nwang@suse.com
- bsc#1069131, compat udev-always-with-vnr and quorum.
- bsc#1069132, fix error message when write resource conf to disk.
- Version 3.3.0
* Fri Sep  9 2016 nwang@suse.com
- bsc#997838, fix error of rename a exist drbd resource.
- Version 3.1.26
* Thu Sep  8 2016 nwang@suse.com
- fate#321158, remove automatic change lvm filter
- Version 3.1.25
* Thu Aug  4 2016 nwang@suse.com
- Syntax change: support resync-rate in disk section, fix bsc#991253
- bsc#992066, replace panic of on-io-error handler to local-io-error
- Version 3.1.24
* Tue Jun  7 2016 igonzalezsosa@suse.com
- Stop generating autodocs (fate#320356)
- Version 3.1.23
* Tue May 31 2016 nwang@suse.com
- bsc#981779, add IP validation check of resource.
- Version 3.1.22
* Thu Apr 21 2016 nwang@suse.com
- bsc#976562, fix error when using hyphen in node name.
* Fri Mar 25 2016 nwang@suse.com
- fate#320398, add require to drbd9.0 for fate#315096.
* Fri Mar 25 2016 nwang@suse.com
- fate#320398, support drbd9 to extend to multiple node
- Syntax change: support read/write automatically node-id.
- Syntax change: support connection-mesh and net section in it.
- Syntax compatible: won't pop up error for connection section.
    not support write connection section.
- Version 3.1.21
* Thu Mar 17 2016 nwang@suse.com
- bsc#971508, many syntax change after drbdv8.4
- Syntax change: support md-flushes in disk section
- Syntax change: protocol option move to net section
- Syntax change: move al-extents/verify-alg from syncer section
    to disk/net section.
- Syntax change: Support options section in conf, but no UI.
- Fix gsub search in in ruby agent
- Version 3.1.20
* Wed Jan 20 2016 nwang@suse.com
- Replace ag_drbd with new generated one by rubygem-racc 1.4.14
* Thu Nov 19 2015 nwang@suse.com
- BSC#955564. Allow user to configure "use_lvmetad" for lvm.
- Version 3.1.19
* Thu Nov 12 2015 nwang@suse.com
- BSC#954393. Support "options" section in global_common.conf
- BSC#954724. Disable "edit/delete" button when no resource.
- BSC#954729. Error message pop up when save configuration after
    edit or delete resource.
- Version 3.1.18
* Mon Sep 21 2015 nwang@suse.com
- BSC#946596. Support both hostname and hostname+domain
- Version 3.1.17
* Mon Sep 14 2015 nwang@suse.com
- BSC#945618. Remove the second dummy help button when
  running as ncurses.
- Version 3.1.16
* Thu Aug 13 2015 nwang@suse.com
- BSC#941567. Fix error message pop up when no res conf in
  fisrt launch.
- Version 3.1.15
* Mon Aug 10 2015 nwang@suse.com
- BSC#941094. Change from /usr/sbin/drbd* to /sbin/drbd*
- Version 3.1.14
* Fri Jul 24 2015 nwang@suse.com
- BSC#939338, using kmp package for drbd8.4.6
- Require drbd-utils for user space.
* Fri May 15 2015 nwang@suse.com
- Feature implementation for SLE12SP1
- Fate#317957, Fate#318555, Fate#318391
- Version 3.1.12
* Mon Dec 22 2014 nwang@suse.com
- BNC#900818. Corresponding change of modification of drbd-utils.
- drbd kernel module default installed in kernel, package drbd
  also be replaced by package drbd-utils.
- This change should co-work with the first drbd-utils version.
- Version 3.1.11
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
* Tue Nov  4 2014 nwang@suse.com
- BNC#903514. Modify the wrong help text.
- Add in Maintenance update.
- Version 3.1.9
* Tue Nov  4 2014 nwang@suse.com
- BNC#901554. Change outdate-peer to fence-peer.
* Mon Oct 27 2014 nwang@suse.com
- BNC#901833. Fix value of "wfc-timeout" and "degr-wfc-timeout"
  can not be shown in GUI.
- Add in Maintenance update.
- Version 3.1.8
* Fri Oct 10 2014 nwang@suse.com
- BNC#898448. Add validation check of node name.
- Add in Maintenance update.
- Version 3.1.7
* Tue Sep  9 2014 nwang@suse.com
- BNC#460178. Exit directly if no any modification.
- Version 3.1.6
* Tue Jul  1 2014 nwang@suse.com
- BNC#884689 and BNC#812061. Enhance the help text.
- Version 3.1.5
* Tue Jul  1 2014 nwang@suse.com
- BNC#885112. Fix finish progress message.
* Thu Jun  5 2014 nwang@suse.com
- BNC#881500. /sbin/drbdadm change to /usr/sbin/drbdadm.
- Version 3.1.4
* Fri May 30 2014 nwang@suse.com
- Merge from dongmao. Fate#315128: let drbd support autoyast"
- Version 3.1.3
* Tue May 27 2014 nwang@suse.com
- Temporarily comment "racc" in Makefile.am.Due to buildrequires:
  rubygem-racc is necessary in yast ci but invalid in ibs.
- version 3.1.2
* Mon May 26 2014 nwang@suse.com
- BNC#876536. Convert Ycp to Ruby based on sle11sp3(sp1).
  Merge sle12 master code to convert branch then merge back
  to master. Did some basic test.
- version 3.1.1
* Fri May  9 2014 nwang@suse.com
- BNC#875677. Change desktop file,move DRBD from Misc to
  High_Availability categorie.
* Wed Sep 18 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Wed Jul 31 2013 yast-devel@opensuse.org
- converted from YCP to Ruby by YCP Killer
  (https://github.com/yast/ycp-killer)
- version 3.0.0
* Thu May  9 2013 lslezak@suse.cz
- added *.spec.in as in all other YaST modules
- removed unused files, packaging fixes
- 2.24.0
* Thu Mar 29 2012 jsuchome@suse.cz
- merged proofed texts
* Mon Jan 12 2009 xwhu@suse.de
- bnc#464116: texts not marked for translation
* Fri Dec 19 2008 xwhu@suse.de
- bnc#459742: drbd module crashes in ncurses mode
- bnc#459747: drbd module doesn't update to the latest drbd.conf
* Wed Nov 19 2008 cmeng@novell.com
- bnc#442758: use another API to set the button lable
* Thu Oct  2 2008 xwhu@suse.de
- Replace ReplaceNextButton with SetNextButton (bnc#429021)
* Wed Jul 16 2008 xwhu@suse.de
- pae was not recognized as a kernel arch (bnc#380074)
* Mon Apr  7 2008 xwhu@suse.de
- bugzilla 291490: typo in resource_conf.ycp
* Mon Jul 30 2007 cmeng@novell.com
- fix bug-295546: resource config get deleted
- refix bug-291766: check also iseries64 and ppc64
* Mon Jul 23 2007 cmeng@novell.com
- fix bug-291766: yast-drbd doesn't install drbd-kmp-<arch> pack
- fix bug-291778: yast-drbd recreate drbd.conf while it doesn't exist
- fix bug-291785: set the default val of protocol even 'advance page' not be accesed
- fix bug-291771: refine some error messages and logs
* Mon Jun 18 2007 xwhu@novell.com
- Change the instruction message about propagating configuration
- Reuse yast-iscsi-client.png
* Thu Apr 26 2007 xwhu@novell.com
- update to version 2.13.1
* Tue Apr 24 2007 xwhu@novell.com
- initial version 2.13.0
